@@ -14,7 +14,7 @@ Usage::
     client: EBSClient = boto3.client("ebs")
     session_client: EBSClient = session.client("ebs")
 """
-from mypy_boto3_ebs.client import EBSClient, EBSClient as Client
+from mypy_boto3_ebs.client import EBSClient as Client, EBSClient
 
 
 __all__ = ("Client", "EBSClient")
